@@ -242,11 +242,13 @@ class TPUAccelerator(Accelerator):
 
         # model hook
         model_ref.optimizer_step(
-            self.trainer.current_epoch,
-            batch_idx, optimizer,
-            opt_idx,
-            lambda_closure,
+            epoch=self.trainer.current_epoch,
+            batch_idx=batch_idx,
+            optimizer=optimizer,
+            optimizer_idx=opt_idx,
+            optimizer_closure=lambda_closure,
             on_tpu=True,
+            using_native_amp=False,
             using_lbfgs=is_lbfgs
         )
 
