@@ -78,7 +78,7 @@ class ModelCheckpoint(Callback):
 
         dirpath: directory to save the model file.
 
-            Example:
+            Example::
 
                 # custom path
                 # saves a file like: my/path/epoch=0.ckpt
@@ -92,7 +92,7 @@ class ModelCheckpoint(Callback):
 
         filename: checkpoint filename. Can contain named formatting options to be auto-filled.
 
-            Example:
+            Example::
 
                 # save any arbitrary metrics like `val_loss`, etc. in name
                 # saves a file like: my/path/epoch=2-val_loss=0.02-other_metric=0.03.ckpt
@@ -104,14 +104,14 @@ class ModelCheckpoint(Callback):
             By default, filename is ``None`` and will be set to ``'{epoch}'``.
 
 
-    Example:
+    Example::
 
         >>> from pytorch_lightning import Trainer
         >>> from pytorch_lightning.callbacks import ModelCheckpoint
 
         # saves checkpoints to 'my/path/' at every epoch
         >>> checkpoint_callback = ModelCheckpoint(dirpath='my/path/')
-        >>> trainer = Trainer(checkpoint_callback=checkpoint_callback)
+        >>> trainer = Trainer(callbacks=[checkpoint_callback])
 
         # save epoch and val_loss in name
         # saves a file like: my/path/sample-mnist-epoch=02-val_loss=0.32.ckpt
@@ -123,7 +123,7 @@ class ModelCheckpoint(Callback):
 
         # retrieve the best checkpoint after training
         checkpoint_callback = ModelCheckpoint(dirpath='my/path/')
-        trainer = Trainer(checkpoint_callback=checkpoint_callback)
+        trainer = Trainer(callbacks=[checkpoint_callback])
         model = ...
         trainer.fit(model)
         checkpoint_callback.best_model_path
