@@ -259,7 +259,7 @@ class Result(Dict):
 
             if options['logger'] and options['on_step']:
                 if isinstance(self[k], Metric):
-                    result[k] = self[k]._forward_cache
+                    result[k] = self[k]._forward_cache.detach()
                 else:
                     result[k] = self[k]
 
@@ -281,7 +281,7 @@ class Result(Dict):
 
             if options['logger'] and options['on_epoch']:
                 if isinstance(self[k], Metric):
-                    result[k] = self[k].compute()
+                    result[k] = self[k].compute().detach()
                 else:
                     result[k] = self[k]
 
@@ -307,7 +307,7 @@ class Result(Dict):
 
             if options['prog_bar'] and options['on_epoch']:
                 if isinstance(self[k], Metric):
-                    result[k] = self[k].compute()
+                    result[k] = self[k].compute().detach()
                 else:
                     result[k] = self[k]
 
