@@ -188,7 +188,7 @@ class LightningLoggerBase(ABC):
                         return val.__name__
                     return _val
                 except Exception:
-                    return val.__name__
+                    return getattr(val, "__name__", None)
             return val
 
         return {key: _sanitize_callable(val) for key, val in params.items()}
