@@ -25,4 +25,6 @@ from pytorch_lightning.metrics.regression import (
     MeanAbsoluteError,
     MeanSquaredLogError,
     ExplainedVariance,
+    PSNR,
+    SSIM,
 )
