@@ -145,12 +145,14 @@ class Metric(nn.Module, ABC):
         self._defaults[name] = deepcopy(default)
         self._reductions[name] = dist_reduce_fx
 
+    @torch.jit.unused
     def forward(self, *args, **kwargs):
         """
         Automatically calls ``update()``. Returns the metric value over inputs if ``compute_on_step`` is True.
         """
         # add current step
-        self.update(*args, **kwargs)
+        with torch.no_grad():
+            self.update(*args, **kwargs)
         self._forward_cache = None
 
         if self.compute_on_step:
