@@ -15,6 +15,10 @@ import torch
 from typing import Any, Callable, Optional, Union
 
 from pytorch_lightning.metrics.metric import Metric
+from pytorch_lightning.metrics.functional.mean_absolute_error import (
+    _mean_absolute_error_update,
+    _mean_absolute_error_compute
+)
 
 
 class MeanAbsoluteError(Metric):
@@ -63,14 +67,13 @@ class MeanAbsoluteError(Metric):
             preds: Predictions from model
             target: Ground truth values
         """
-        self._check_same_shape(preds, target)
-        abs_error = torch.abs(preds - target)
+        sum_abs_error, n_obs = _mean_absolute_error_update(preds, target)
 
-        self.sum_abs_error += torch.sum(abs_error)
-        self.total += target.numel()
+        self.sum_abs_error += sum_abs_error
+        self.total += n_obs
 
     def compute(self):
         """
         Computes mean absolute error over state.
         """
-        return self.sum_abs_error / self.total
+        return _mean_absolute_error_compute(self.sum_abs_error, self.total)
